@@ -18,7 +18,6 @@ from itertools import chain
 import re
 import uuid
 
-from six import string_types
 from stix2patterns.v21.pattern import Pattern
 
 from . import enums
@@ -157,7 +156,8 @@ def uuid_check(instance):
         return
 
     object_id = uuid.UUID(instance['id'].split("--")[-1])
-    if has_cyber_observable_data(instance, "2.1") and instance['type'] != 'process':
+    if (has_cyber_observable_data(instance, "2.1") and
+            instance['type'] not in ['observed-data', 'process']):
         if object_id.version != 5:
             yield JSONError("Cyber Observable ID value %s is not a valid UUIDv5 ID."
                             % instance['id'], instance['id'], 'uuid-check')
@@ -707,7 +707,7 @@ def custom_observable_properties_prefix_strict(instance):
                     if (ext_key in enums.OBSERVABLE_EXTENSION_EMBEDDED_PROPERTIES and
                             ext_prop in enums.OBSERVABLE_EXTENSION_EMBEDDED_PROPERTIES[ext_key]):
                         for embed_prop in instance['extensions'][ext_key][ext_prop]:
-                            if not (isinstance(embed_prop, Iterable) and not isinstance(embed_prop, string_types)):
+                            if not (isinstance(embed_prop, Iterable) and not isinstance(embed_prop, str)):
                                 embed_prop = [embed_prop]
                             for p in embed_prop:
                                 if (p not in enums.OBSERVABLE_EXTENSION_EMBEDDED_PROPERTIES[ext_key][ext_prop] and
@@ -781,7 +781,7 @@ def custom_observable_properties_prefix_lax(instance):
                     if (ext_key in enums.OBSERVABLE_EXTENSION_EMBEDDED_PROPERTIES and
                             ext_prop in enums.OBSERVABLE_EXTENSION_EMBEDDED_PROPERTIES[ext_key]):
                         for embed_prop in instance['extensions'][ext_key][ext_prop]:
-                            if not (isinstance(embed_prop, Iterable) and not isinstance(embed_prop, string_types)):
+                            if not (isinstance(embed_prop, Iterable) and not isinstance(embed_prop, str)):
                                 embed_prop = [embed_prop]
                             for p in embed_prop:
                                 if (p not in enums.OBSERVABLE_EXTENSION_EMBEDDED_PROPERTIES[ext_key][ext_prop] and
@@ -1130,7 +1130,7 @@ def types_strict(instance):
                                 % (key, obj['type']), instance['id'])
 
     if (instance['type'] == 'indicator' and instance.get('pattern_type', '') == 'stix' and
-            isinstance(instance.get('pattern', ''), string_types)):
+            isinstance(instance.get('pattern', ''), str)):
         pattern = instance['pattern']
         p = Pattern(pattern)
         inspection = p.inspect().comparisons
@@ -1163,7 +1163,7 @@ def properties_strict(instance):
                 yield error
 
     if (instance['type'] == 'indicator' and instance.get('pattern_type', '') == 'stix' and
-            isinstance(instance.get('pattern', ''), string_types)):
+            isinstance(instance.get('pattern', ''), str)):
         pattern = instance['pattern']
         p = Pattern(pattern)
         inspection = p.inspect().comparisons
